==> finalcut_0.8.0.orig.tar.gz: finalcut-0.8.0/final/widget/fcheckbox.h <==
/***********************************************************************
* fcheckbox.h - Widget FCheckBox                                       *
*                                                                      *
* This file is part of the FINAL CUT widget toolkit                    *
*                                                                      *
* Copyright 2014-2021 Markus Gans                                      *
*                                                                      *
* FINAL CUT is free software; you can redistribute it and/or modify    *
* it under the terms of the GNU Lesser General Public License as       *
* published by the Free Software Foundation; either version 3 of       *
* the License, or (at your option) any later version.                  *
*                                                                      *
* FINAL CUT is distributed in the hope that it will be useful, but     *
* WITHOUT ANY WARRANTY; without even the implied warranty of           *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
* GNU Lesser General Public License for more details.                  *
*                                                                      *
* You should have received a copy of the GNU Lesser General Public     *
* License along with this program.  If not, see                        *
* <http://www.gnu.org/licenses/>.                                      *
***********************************************************************/

/*  Inheritance diagram
 *  ═══════════════════
 *
 * ▕▔▔▔▔▔▔▔▔▔▏ ▕▔▔▔▔▔▔▔▔▔▏
 * ▕ FVTerm  ▏ ▕ FObject ▏
 * ▕▁▁▁▁▁▁▁▁▁▏ ▕▁▁▁▁▁▁▁▁▁▏
 *      ▲           ▲
 *      │           │
 *      └─────┬─────┘
 *            │
 *       ▕▔▔▔▔▔▔▔▔▔▏
 *       ▕ FWidget ▏
 *       ▕▁▁▁▁▁▁▁▁▁▏
 *            ▲
 *            │
 *    ▕▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▏
 *    ▕ FToggleButton ▏
 *    ▕▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▏
 *            ▲
 *            │
 *      ▕▔▔▔▔▔▔▔▔▔▔▔▏
 *      ▕ FCheckBox ▏
 *      ▕▁▁▁▁▁▁▁▁▁▁▁▏
 */

#ifndef FCHECKBOX_H
#define FCHECKBOX_H

#if !defined (USE_FINAL_H) && !defined (COMPILE_FINAL_CUT)
  #error "Only <final/final.h> can be included directly."
#endif

#include "final/widget/ftogglebutton.h"

namespace finalcut
{

//----------------------------------------------------------------------
// class FCheckBox
//----------------------------------------------------------------------

class FCheckBox : public FToggleButton
{
  public:
    // Constructors
    explicit FCheckBox (FWidget* = nullptr);
    explicit FCheckBox (const FString&, FWidget* = nullptr);

    // Destructor
    ~FCheckBox() noexcept override;

    // Accessor
    FString       getClassName() const override;

  private:
    // Methods
    void          init();
    void          draw() override;
    void          drawCheckButton();
    void          drawChecked();
    void          drawUnchecked();
};

// FCheckBox inline functions
//----------------------------------------------------------------------
inline FString FCheckBox::getClassName() const
{ return "FCheckBox"; }

}  // namespace finalcut

#endif  // FCHECKBOX_H

==> finalcut_0.9.1.orig.tar.gz: finalcut-0.9.1/final/widget/fcheckbox.h <==
/***********************************************************************
* fcheckbox.h - Widget FCheckBox                                       *
*                                                                      *
* This file is part of the FINAL CUT widget toolkit                    *
*                                                                      *
* Copyright 2014-2022 Markus Gans                                      *
*                                                                      *
* FINAL CUT is free software; you can redistribute it and/or modify    *
* it under the terms of the GNU Lesser General Public License as       *
* published by the Free Software Foundation; either version 3 of       *
* the License, or (at your option) any later version.                  *
*                                                                      *
* FINAL CUT is distributed in the hope that it will be useful, but     *
* WITHOUT ANY WARRANTY; without even the implied warranty of           *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
* GNU Lesser General Public License for more details.                  *
*                                                                      *
* You should have received a copy of the GNU Lesser General Public     *
* License along with this program.  If not, see                        *
* <http://www.gnu.org/licenses/>.                                      *
***********************************************************************/

/*  Inheritance diagram
 *  ═══════════════════
 *
 * ▕▔▔▔▔▔▔▔▔▔▏ ▕▔▔▔▔▔▔▔▔▔▏
 * ▕ FVTerm  ▏ ▕ FObject ▏
 * ▕▁▁▁▁▁▁▁▁▁▏ ▕▁▁▁▁▁▁▁▁▁▏
 *      ▲           ▲
 *      │           │
 *      └─────┬─────┘
 *            │
 *       ▕▔▔▔▔▔▔▔▔▔▏
 *       ▕ FWidget ▏
 *       ▕▁▁▁▁▁▁▁▁▁▏
 *            ▲
 *            │
 *    ▕▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▏
 *    ▕ FToggleButton ▏
 *    ▕▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▏
 *            ▲
 *            │
 *      ▕▔▔▔▔▔▔▔▔▔▔▔▏
 *      ▕ FCheckBox ▏
 *      ▕▁▁▁▁▁▁▁▁▁▁▁▏
 */

#ifndef FCHECKBOX_H
#define FCHECKBOX_H

#if !defined (USE_FINAL_H) && !defined (COMPILE_FINAL_CUT)
  #error "Only <final/final.h> can be included directly."
#endif

#include "final/widget/ftogglebutton.h"

namespace finalcut
{

//----------------------------------------------------------------------
// class FCheckBox
//----------------------------------------------------------------------

class FCheckBox : public FToggleButton
{
  public:
    // Constructors
    explicit FCheckBox (FWidget* = nullptr);
    explicit FCheckBox (const FString&, FWidget* = nullptr);

    // Destructor
    ~FCheckBox() noexcept override;

    // Accessor
    auto getClassName() const -> FString override;

  private:
    // Methods
    void init();
    void draw() override;
    void drawCheckButton();
    void drawChecked();
    void drawUnchecked();
};

// FCheckBox inline functions
//----------------------------------------------------------------------
inline auto FCheckBox::getClassName() const -> FString
{ return "FCheckBox"; }

}  // namespace finalcut

#endif  // FCHECKBOX_H
